@@ -176,12 +176,12 @@ class Content(PolymorphicIndexable, PolymorphicModel):
     last_modified = models.DateTimeField(auto_now=True, default=timezone.now)
     title = models.CharField(max_length=512)
     slug = models.SlugField(blank=True, default='')
-    description = models.TextField(max_length=1024, blank=True, default='')
+    description = models.TextField(max_length=1024, blank=True, default="")
     _thumbnail = ImageField(null=True, blank=True, editable=False)
 
     authors = models.ManyToManyField(settings.AUTH_USER_MODEL)
-    feature_type = models.CharField(max_length=255, null=True, blank=True)  # "New in Brief", "Newswire", etc.
-    subhead = models.CharField(max_length=255, null=True, blank=True)
+    feature_type = models.CharField(max_length=255, blank=True, default="")
+    subhead = models.CharField(max_length=255, blank=True, default="")
 
     tags = models.ManyToManyField(Tag, blank=True)
 
